OC.L10N.register(
    "mail",
    {
    "Mail" : "Поща",
    "Inbox" : "Входяши",
    "Sent" : "Изпратени",
    "Drafts" : "Чернови",
    "Archive" : "Архив",
    "Trash" : "Кошче",
    "Junk" : "Спам",
    "All" : "Всички",
    "Favorites" : "Любими",
    "Auto detect failed. Please use manual mode." : "Неуспешни автоматични настройки. Моля, използвай ръчен режим.",
    "Creating account failed: " : "Неуспешно създаване на профил:",
    "Delete permanently" : "Изтрий завинаги",
    "IMAP web client" : "IMAP уеб клиент",
    "Easy to use email client which connects to your mail server via IMAP and SMTP." : "Имейл клиент, който поддържа IMAP и SMTP.",
    "Auto" : "Автоматично",
    "Name" : "Име",
    "Mail Address" : "Имейл адрес",
    "Password" : "Парола",
    "Manual" : "Ръчно",
    "IMAP Settings" : "IMAP настройки",
    "IMAP Host" : "IMAP сървър",
    "IMAP Security" : "IMAP сигурност",
    "None" : "Няма",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "IMAP порт",
    "IMAP User" : "IMAP потребител",
    "IMAP Password" : "IMAP парола",
    "SMTP Settings" : "SMTP настройки",
    "SMTP Host" : "SMTP сървър",
    "SMTP Security" : "SMTP сигурност",
    "SMTP Port" : "SMTP порт",
    "SMTP User" : "SMTP потребител",
    "SMTP Password" : "SMTP парола",
    "Save" : "Запис",
    "Connect" : "Свържи",
    "Add mail account" : "Добавяне на профил",
    "Keyboard shortcuts" : "Бързи клавиши",
    "from" : "от",
    "to" : "до",
    "+ cc/bcc" : "+ cc/bcc",
    "cc" : "ЯК",
    "bcc" : "СК",
    "Subject" : "Тема",
    "Draft saved" : "Черновата записана",
    "Sending …" : "Изпращане...",
    "Retry" : "Опитай отново",
    "Message sent!" : "Съобщението е изпратено!",
    "Send" : "Изпрати",
    "Uploading {percent}% …" : "Качване {percent}% …",
    "Upload attachment" : "Качи прикачен файл/ове",
    "Choose a file to add as attachment" : "Избери файл за прикачване",
    "Draft: " : "Чернова: ",
    "Mark read" : "Маркирай като прочетено",
    "Mark unread" : "Маркирай като непрочетено",
    "Delete" : "Изтриване",
    "Loading messages" : "Зареждане на съобщенията",
    "Could not load your message" : "Вашето съобщение не може да бъде заредено",
    "Download attachment" : "Изтегли прикачените файлове",
    "Save to Files" : "Запази във Файлове",
    "Choose a folder to store the attachment in" : "Избери папка, където да бъде запазен прикаченият файл",
    "New message" : "Ново съобщение",
    "Settings" : "Настройки",
    "Edit" : "Редакция",
    "Add folder" : "Добави папка",
    "Show all folders" : "Покажи всички папки",
    "Collapse folders" : "Свиване на папките",
    "Loading …" : "Зарежда …",
    "Mark all as read" : "Маркирай всички като прочетени",
    "Mark all messages of this folder as read" : "Маркирай всички съобщения в тази папка като прочетени",
    "Add subfolder" : "Добави подпапка",
    "No message selected" : "Не е избрано съобщение",
    "Signature" : "Подпис",
    "Account Settings" : "Настройка на акаунта",
    "Mail server" : "Имейл сървър",
    "Compose new message" : "Създай ново съобщение",
    "Search" : "Търси",
    "Refresh" : "Опресняване",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n ново съобщение \nот {from}","%n нови съобщения\nот {from}"],
    "Nextcloud Mail" : "Nextcloud Е-Мейл",
    "All inboxes" : "Всички",
    "Could not load {tag}{name}{endtag}" : "{tag}{name}{endtag} не може да бъде зареден",
    "There was a problem loading {tag}{name}{endtag}" : "Проблем при зареждане на {tag}{name}{endtag}",
    "Could not load the desired message" : "Желаното съобщение не може да бъде заредено",
    "Could not load the message" : "Съобщението не може да бъде заредено",
    "Error loading message" : "Грешка при зареждане съобщението",
    "Forwarding to %s" : "Препращане към %s",
    "The link leads to %s" : "Връзката води до %s",
    "Continue to %s" : "Продължи към %s"
},
"nplurals=2; plural=(n != 1);");
